turbofeeds

Package turbofeeds |
[hide private]

# Package turbofeeds

source code

Submodules | [hide private]
turbofeeds.controllers: TurboFeed controllers for RSS/Atom feeds handling. turbofeeds.release: TurboGears controller and widgets for feed handling. turbofeeds.templates turbofeeds.util: TurboFeed utility functions. turbofeeds.widgets: TurboFeed widgets for RSS/Atom feeds handling.

Classes | [hide private]
| FeedController Controller for generating feeds in multiple formats.
| FeedLinks A list of links to feeds for all supported formats.

Functions | [hide private]
absolute_url(suffix=`'````'`, params=None, **kw) Returns the absolute URL to this server, appending 'suffix' if given. | source code
xml_stylesheet(href, type=`'``text/css``'`) Returns an xml-stylesheet processing instruction element for given URL. | source code

Variables | [hide private]
| static_dir = ``'``/home/chris/tmp/build/TurboFeeds/turbofeeds/static``'``

Function Details | [hide private]

### xml_stylesheet(href, type=`'``text/css``'`) | source code
Returns an xml-stylesheet processing instruction element for given URL. `href` can be a string with the URL to the stylesheet or a dict with members `href` and `type` (see below) or a callable returning either. `type` specifies the value of the "type" atribute of the PI. The default type is 'text/css'.